@@ -130,10 +130,13 @@ class Benchmark(AppEndpoint, BenchmarkMixin, RunMixin, TimeSeriesPlotMixin):
             run=run,
             form=form,
             resources=bokeh.resources.CDN.render(),
-            plot_history=self.get_history_plot(benchmark),
+            plot_history=self.get_history_plot(benchmark, run),
         )
 
     def get(self, benchmark_id):
+        if self.public_data_off():
+            return self.redirect("app.login")
+
         benchmark, run = self._get_benchmark_and_run(benchmark_id)
         return self.page(benchmark, run, DeleteForm())
 
@@ -187,6 +190,9 @@ class BenchmarkList(AppEndpoint, ContextMixin):
         )
 
     def get(self):
+        if self.public_data_off():
+            return self.redirect("app.login")
+
         benchmarks, response = self._get_benchmarks()
         if response.status_code != 200:
             self.flash("Error getting benchmarks.")
