@@ -259,6 +259,7 @@
                             "id": "some-commit-uuid-1",
                             "links": {
                                 "list": "http://localhost/api/commits/",
+                                "parent": "http://localhost/api/commits/some-commit-parent-uuid-1/",
                                 "self": "http://localhost/api/commits/some-commit-uuid-1/",
                             },
                             "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
@@ -283,6 +284,7 @@
                                 "id": "some-commit-uuid-1",
                                 "links": {
                                     "list": "http://localhost/api/commits/",
+                                    "parent": "http://localhost/api/commits/some-commit-parent-uuid-1/",
                                     "self": "http://localhost/api/commits/some-commit-uuid-1/",
                                 },
                                 "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
@@ -471,7 +473,7 @@
                                 "mean": "0.036369",
                                 "message": "ARROW-11771: [Developer][Archery] Move benchmark tests (so CI runs them)",
                                 "repository": "https://github.com/apache/arrow",
-                                "run_name": "commit: 02addad336ba19a654f9c857ede546331be7b631",
+                                "run_name": "some run name",
                                 "sha": "02addad336ba19a654f9c857ede546331be7b631",
                                 "timestamp": "2021-02-25T01:02:51",
                                 "unit": "s",
@@ -516,6 +518,8 @@
                             "cpu_l3_cache_bytes": 4194304,
                             "cpu_model_name": "Intel(R) Core(TM) i7-7567U CPU @ 3.50GHz",
                             "cpu_thread_count": 4,
+                            "gpu_count": 2,
+                            "gpu_product_names": ["Tesla T4", "GeForce GTX 1060 3GB"],
                             "id": "some-machine-uuid-1",
                             "kernel_name": "19.6.0",
                             "links": {
@@ -545,6 +549,11 @@
                                 "cpu_l3_cache_bytes": 4194304,
                                 "cpu_model_name": "Intel(R) Core(TM) i7-7567U CPU @ 3.50GHz",
                                 "cpu_thread_count": 4,
+                                "gpu_count": 2,
+                                "gpu_product_names": [
+                                    "Tesla T4",
+                                    "GeForce GTX 1060 3GB",
+                                ],
                                 "id": "some-machine-uuid-1",
                                 "kernel_name": "19.6.0",
                                 "links": {
@@ -592,7 +601,9 @@
                             "id": "some-run-uuid-1",
                             "links": {
                                 "baseline": "http://localhost/api/runs/some-run-uuid-0/",
+                                "commit": "http://localhost/api/commits/some-commit-uuid-1/",
                                 "list": "http://localhost/api/runs/",
+                                "machine": "http://localhost/api/machines/some-machine-uuid-1/",
                                 "self": "http://localhost/api/runs/some-run-uuid-1/",
                             },
                             "machine": {
@@ -605,6 +616,11 @@
                                 "cpu_l3_cache_bytes": 4194304,
                                 "cpu_model_name": "Intel(R) Core(TM) i7-7567U CPU @ 3.50GHz",
                                 "cpu_thread_count": 4,
+                                "gpu_count": 2,
+                                "gpu_product_names": [
+                                    "Tesla T4",
+                                    "GeForce GTX 1060 3GB",
+                                ],
                                 "id": "some-machine-uuid-1",
                                 "kernel_name": "19.6.0",
                                 "memory_bytes": 17179869184,
@@ -612,7 +628,7 @@
                                 "os_name": "macOS",
                                 "os_version": "10.15.7",
                             },
-                            "name": "commit: 02addad336ba19a654f9c857ede546331be7b631",
+                            "name": "some run name",
                             "timestamp": "2021-02-04T17:22:05.225583",
                         }
                     }
@@ -638,7 +654,9 @@
                                 },
                                 "id": "some-run-uuid-1",
                                 "links": {
+                                    "commit": "http://localhost/api/commits/some-commit-uuid-1/",
                                     "list": "http://localhost/api/runs/",
+                                    "machine": "http://localhost/api/machines/some-machine-uuid-1/",
                                     "self": "http://localhost/api/runs/some-run-uuid-1/",
                                 },
                                 "machine": {
@@ -651,6 +669,11 @@
                                     "cpu_l3_cache_bytes": 4194304,
                                     "cpu_model_name": "Intel(R) Core(TM) i7-7567U CPU @ 3.50GHz",
                                     "cpu_thread_count": 4,
+                                    "gpu_count": 2,
+                                    "gpu_product_names": [
+                                        "Tesla T4",
+                                        "GeForce GTX 1060 3GB",
+                                    ],
                                     "id": "some-machine-uuid-1",
                                     "kernel_name": "19.6.0",
                                     "memory_bytes": 17179869184,
@@ -658,7 +681,7 @@
                                     "os_name": "macOS",
                                     "os_version": "10.15.7",
                                 },
-                                "name": "commit: 02addad336ba19a654f9c857ede546331be7b631",
+                                "name": "some run name",
                                 "timestamp": "2021-02-04T17:22:05.225583",
                             }
                         ]
@@ -813,6 +836,8 @@
                     "cpu_l3_cache_bytes": {"type": "integer"},
                     "cpu_model_name": {"type": "string"},
                     "cpu_thread_count": {"type": "integer"},
+                    "gpu_count": {"type": "integer"},
+                    "gpu_product_names": {"items": {"type": "string"}, "type": "array"},
                     "kernel_name": {"type": "string"},
                     "memory_bytes": {"type": "integer"},
                     "name": {"type": "string"},
@@ -829,6 +854,8 @@
                     "cpu_l3_cache_bytes",
                     "cpu_model_name",
                     "cpu_thread_count",
+                    "gpu_count",
+                    "gpu_product_names",
                     "kernel_name",
                     "memory_bytes",
                     "name",
@@ -1240,6 +1267,23 @@
             }
         },
         "/api/runs/{run_id}/": {
+            "delete": {
+                "description": "Delete a run.",
+                "parameters": [
+                    {
+                        "in": "path",
+                        "name": "run_id",
+                        "required": True,
+                        "schema": {"type": "string"},
+                    }
+                ],
+                "responses": {
+                    "204": {"$ref": "#/components/responses/204"},
+                    "401": {"$ref": "#/components/responses/401"},
+                    "404": {"$ref": "#/components/responses/404"},
+                },
+                "tags": ["Runs"],
+            },
             "get": {
                 "description": "Get a run.",
                 "parameters": [
@@ -1256,7 +1300,7 @@
                     "404": {"$ref": "#/components/responses/404"},
                 },
                 "tags": ["Runs"],
-            }
+            },
         },
         "/api/users/": {
             "get": {
